@@ -5,12 +5,16 @@
 
 import sys
 import unittest
+import warnings
 
 from ClusterShell.RangeSet import RangeSet, RangeSetND
 
 
 class RangeSetNDTest(unittest.TestCase):
 
+    def setUp(self):
+        warnings.simplefilter("always")
+
     def _testRS(self, test, res, length):
         r1 = RangeSetND(test, autostep=3)
         self.assertEqual(str(r1), res)
@@ -33,8 +37,9 @@ class RangeSetNDTest(unittest.TestCase):
     def test_vectors(self):
         rn = RangeSetND([["0-10", "1-2"], ["5-60", "2"]])
         # vectors() should perform automatic folding
-        self.assertEqual([[RangeSet("0-60"), RangeSet("2")], [RangeSet("0-10"), RangeSet("1")]], list(rn.vectors()))
-        self.assertEqual(str(rn), "0-60; 2\n0-10; 1\n")
+
+        self.assertEqual([[RangeSet("11-60"), RangeSet("2")], [RangeSet("0-10"), RangeSet("1-2")],], list(rn.vectors()))
+        self.assertEqual(str(rn), "11-60; 2\n0-10; 1-2\n")
         self.assertEqual(len(rn), 72)
 
     def test_nonzero(self):
@@ -137,9 +142,9 @@ class RangeSetNDTest(unittest.TestCase):
         self._testRS([["10-30", "3", "5"], ["10-30", "2", "6"]], "10-30; 2; 6\n10-30; 3; 5\n", 42)
         self._testRS([["10-30", "2", "6"], ["10-30", "3", "5"]], "10-30; 2; 6\n10-30; 3; 5\n", 42)
         # sorting condition (4)
-        self._testRS([["10-30", "2,6", "6"], ["10-30", "2-3", "5"]], "10-30; 2-3; 5\n10-30; 2,6; 6\n", 84)
+        self._testRS([["10-30", "2,6", "6"], ["10-30", "2-3", "5"]], "10-30; 2; 5-6\n10-30; 3; 5\n10-30; 6; 6\n", 84)
         # the following test triggers folding loop protection
-        self._testRS([["40-60", "5"], ["30-50", "6"]], "30-50; 6\n40-60; 5\n", 42)
+        self._testRS([["40-60", "5"], ["30-50", "6"]], "40-50; 5-6\n30-39; 6\n51-60; 5\n", 42)
         # 1D
         self._testRS([["40-60"], ["10-12"]], "10-12,40-60\n", 24)
 
@@ -153,11 +158,11 @@ class RangeSetNDTest(unittest.TestCase):
         self._testRS([["0-2", "1-2"], ["3", "1-3"]],
                      "0-2; 1-2\n3; 1-3\n", 9)
         self._testRS([["0-2", "1-2"], ["1-3", "1-3"]],
-                     "1-2; 1-3\n0,3; 1-2\n3; 3\n", 11)
+                     "1-3; 1-3\n0; 1-2\n", 11)
         self._testRS([["0-2", "1-2", "0-4"], ["3", "1-2", "0-5"]],
                      "0-2; 1-2; 0-4\n3; 1-2; 0-5\n", 42)
         self._testRS([["0-2", "1-2", "0-4"], ["1-3", "1-3", "0-4"]],
-                     "1-2; 1-3; 0-4\n0,3; 1-2; 0-4\n3; 3; 0-4\n", 55)
+                     "1-3; 1-3; 0-4\n0; 1-2; 0-4\n", 55)
 
         # triggers full expand heuristic
         veclist = [item for x in range(0, 22, 2) for item in [(x,0), (x,1)]]
@@ -165,25 +170,25 @@ class RangeSetNDTest(unittest.TestCase):
 
         # the following test triggers folding loop protection
         self._testRS([["0-100", "50-200"], ["2-101", "49"]],
-                     "0-100; 50-200\n2-101; 49\n", 15351)
+                     "2-100; 49-200\n0-1; 50-200\n101; 49\n", 15351)
         # the following test triggers full expand
         veclist = []
         for v1, v2, v3 in zip(range(30), range(5, 35), range(10, 40)):
             veclist.append((v1, v2, v3))
-        self._testRS(veclist, "0; 5; 10\n1; 6; 11\n2; 7; 12\n3; 8; 13\n4; 9; 14\n5; 10; 15\n6; 11; 16\n7; 12; 17\n8; 13; 18\n9; 14; 19\n10; 15; 20\n11; 16; 21\n12; 17; 22\n13; 18; 23\n14; 19; 24\n15; 20; 25\n16; 21; 26\n17; 22; 27\n18; 23; 28\n19; 24; 29\n20; 25; 30\n21; 26; 31\n22; 27; 32\n23; 28; 33\n24; 29; 34\n25; 30; 35\n26; 31; 36\n27; 32; 37\n28; 33; 38\n29; 34; 39\n", 30)
+        self._testRS(veclist, "0; 5; 10\n1; 6; 11\n10; 15; 20\n11; 16; 21\n12; 17; 22\n13; 18; 23\n14; 19; 24\n15; 20; 25\n16; 21; 26\n17; 22; 27\n18; 23; 28\n19; 24; 29\n2; 7; 12\n20; 25; 30\n21; 26; 31\n22; 27; 32\n23; 28; 33\n24; 29; 34\n25; 30; 35\n26; 31; 36\n27; 32; 37\n28; 33; 38\n29; 34; 39\n3; 8; 13\n4; 9; 14\n5; 10; 15\n6; 11; 16\n7; 12; 17\n8; 13; 18\n9; 14; 19\n", 30)
 
     def test_union(self):
         rn1 = RangeSetND([["10-100", "1-3"], ["1100-1300", "2-3"]])
         self.assertEqual(str(rn1), "1100-1300; 2-3\n10-100; 1-3\n")
         self.assertEqual(len(rn1), 675)
         rn2 = RangeSetND([["1100-1200", "1"], ["10-49", "1,3"]])
-        self.assertEqual(str(rn2), "1100-1200; 1\n10-49; 1,3\n")
+        self.assertEqual(str(rn2), "12-13,1100-1200; 1\n10-11,14-49; 1,3\n12-13; 3\n")
         self.assertEqual(len(rn2), 181)
         rnu = rn1.union(rn2)
-        self.assertEqual(str(rnu), "1100-1300; 2-3\n10-100; 1-3\n1100-1200; 1\n")
+        self.assertEqual(str(rnu), "10-100,1100-1200; 1-3\n1201-1300; 2-3\n")
         self.assertEqual(len(rnu), 776)
         rnu2 = rn1 | rn2
-        self.assertEqual(str(rnu2), "1100-1300; 2-3\n10-100; 1-3\n1100-1200; 1\n")
+        self.assertEqual(str(rnu2), "10-100,1100-1200; 1-3\n1201-1300; 2-3\n")
         self.assertEqual(len(rnu2), 776)
         self.assertEqual(rnu, rnu2) # btw test __eq__
         self.assertNotEqual(rnu, rn1) # btw test __eq__
@@ -198,7 +203,7 @@ class RangeSetNDTest(unittest.TestCase):
             rn1 = RangeSetND([["10", "10-13"], ["10", "9-12"]])
             rn2 = RangeSetND([["1100-1200", "1"], ["10-49", "1,3"]])
             rn1 |= rn2
-            self.assertEqual(str(rn2), "1100-1200; 1\n10-49; 1,3\n")
+            self.assertEqual(str(rn2), "12-13,1100-1200; 1\n10-11,14-49; 1,3\n12-13; 3\n")
             self.assertEqual(len(rn2), 181)
             rn2 = set([3, 5])
             self.assertRaises(TypeError, rn1.__ior__, rn2)
@@ -252,7 +257,7 @@ class RangeSetNDTest(unittest.TestCase):
         rn2 = RangeSetND([["10", "10"], ["9", "12-15"]])
         rn1.difference_update(rn2)
         self.assertEqual(len(rn1), 8)
-        self.assertEqual(str(rn1), "8; 12-15\n10; 9,11-13\n")
+        self.assertEqual(str(rn1), "10; 9,11-13\n8; 12-15\n")
 
         rn1 = RangeSetND([["10", "10-13"], ["10", "9-12"], ["8-9", "12-15"]])
         rn2 = RangeSetND([["10", "10"], ["9", "12-15"], ["10-12", "11-15"], ["11", "14"]])
@@ -264,10 +269,7 @@ class RangeSetNDTest(unittest.TestCase):
         rn2 = RangeSetND([["10", "10"], ["9", "12-15"], ["10-12", "11-15"], ["11", "14"]])
         rn1.difference_update(rn2)
         self.assertEqual(len(rn1), 7)
-        # no pre-fold (self._veclist)
-        self.assertEqual(str(rn1), "8; 12-15\n9-10; 16\n10; 9\n")
-        # pre-fold (self.veclist)
-        #self.assertEqual(str(rn1), "8; 12-15\n10; 9,16\n9; 16\n")
+        self.assertEqual(str(rn1), "8; 12-15\n10; 9,16\n9; 16\n")
 
         # strict mode
         rn1 = RangeSetND([["10", "10-13"], ["10", "9-12"], ["8-9", "12-15"]])
@@ -337,7 +339,7 @@ class RangeSetNDTest(unittest.TestCase):
         rn2 = RangeSetND([["10", "10"], ["9", "12-15"], ["10-12", "11-15"], ["11", "14"]])
         rn1.intersection_update(rn2)
         self.assertEqual(len(rn1), 8)
-        self.assertEqual(str(rn1), "9; 12-15\n10; 10-13\n")
+        self.assertEqual(str(rn1), "10; 10-13\n9; 12-15\n")
 
         rn1 = RangeSetND([["10", "10-13"], ["10", "9-12"], ["8-9", "12-15"], ["10", "10-13"], ["10", "12-16"], ["9", "13-16"]])
         rn2 = RangeSetND([["10", "10"], ["9", "12-15"], ["10-12", "11-15"], ["11", "14"]])
@@ -392,26 +394,26 @@ class RangeSetNDTest(unittest.TestCase):
     def test_getitem(self):
         rn1 = RangeSetND([["10", "10-13"], ["0-3", "1-2"]])
         self.assertEqual(len(rn1), 12)
-        self.assertEqual(rn1[0], (0, 1))
-        self.assertEqual(rn1[1], (0, 2))
-        self.assertEqual(rn1[2], (1, 1))
-        self.assertEqual(rn1[3], (1, 2))
-        self.assertEqual(rn1[4], (2, 1))
-        self.assertEqual(rn1[5], (2, 2))
-        self.assertEqual(rn1[6], (3, 1))
-        self.assertEqual(rn1[7], (3, 2))
-        self.assertEqual(rn1[8], (10, 10))
-        self.assertEqual(rn1[9], (10, 11))
-        self.assertEqual(rn1[10], (10, 12))
-        self.assertEqual(rn1[11], (10, 13))
+        self.assertEqual(rn1[0], ('0', '1'))
+        self.assertEqual(rn1[1], ('0', '2'))
+        self.assertEqual(rn1[2], ('1', '1'))
+        self.assertEqual(rn1[3], ('1', '2'))
+        self.assertEqual(rn1[4], ('2', '1'))
+        self.assertEqual(rn1[5], ('2', '2'))
+        self.assertEqual(rn1[6], ('3', '1'))
+        self.assertEqual(rn1[7], ('3', '2'))
+        self.assertEqual(rn1[8], ('10', '10'))
+        self.assertEqual(rn1[9], ('10', '11'))
+        self.assertEqual(rn1[10], ('10', '12'))
+        self.assertEqual(rn1[11], ('10', '13'))
         self.assertRaises(IndexError, rn1.__getitem__, 12)
         # negative indices
-        self.assertEqual(rn1[-1], (10, 13))
-        self.assertEqual(rn1[-2], (10, 12))
-        self.assertEqual(rn1[-3], (10, 11))
-        self.assertEqual(rn1[-4], (10, 10))
-        self.assertEqual(rn1[-5], (3, 2))
-        self.assertEqual(rn1[-12], (0, 1))
+        self.assertEqual(rn1[-1], ('10', '13'))
+        self.assertEqual(rn1[-2], ('10', '12'))
+        self.assertEqual(rn1[-3], ('10', '11'))
+        self.assertEqual(rn1[-4], ('10', '10'))
+        self.assertEqual(rn1[-5], ('3', '2'))
+        self.assertEqual(rn1[-12], ('0', '1'))
         self.assertRaises(IndexError, rn1.__getitem__, -13)
         self.assertRaises(TypeError, rn1.__getitem__, "foo")
 
@@ -447,12 +449,13 @@ class RangeSetNDTest(unittest.TestCase):
     def test_iter(self):
         rn0 = RangeSetND([['1-2', '3'], ['1-2', '4'], ['2-6', '6-9,11']])
         self.assertEqual(len([r for r in rn0]), len(rn0))
-        self.assertEqual([(2, 6), (2, 7), (2, 8), (2, 9), (2, 11), (3, 6),
-                          (3, 7), (3, 8), (3, 9), (3, 11), (4, 6), (4, 7),
-                          (4, 8), (4, 9), (4, 11), (5, 6), (5, 7), (5, 8),
-                          (5, 9), (5, 11), (6, 6), (6, 7), (6, 8), (6, 9),
-                          (6, 11), (1, 3), (1, 4), (2, 3), (2, 4)],
-                         [r for r in rn0])
+        # at this time, iter nD is not sorted
+        self.assertEqual([('3', '6'), ('3', '7'), ('3', '8'), ('3', '9'), ('3', '11'), ('4', '6'),
+                          ('4', '7'), ('4', '8'), ('4', '9'), ('4', '11'), ('5', '6'), ('5', '7'),
+                          ('5', '8'), ('5', '9'), ('5', '11'), ('6', '6'), ('6', '7'), ('6', '8'),
+                          ('6', '9'), ('6', '11'), ('2', '3'), ('2', '4'), ('2', '6'), ('2', '7'),
+                          ('2', '8'), ('2', '9'), ('2', '11'), ('1', '3'), ('1', '4')],
+                        [r for r in rn0])
 
     def test_pads(self):
         rn0 = RangeSetND()
@@ -460,19 +463,18 @@ class RangeSetNDTest(unittest.TestCase):
         self.assertEqual(len(rn0), 0)
         self.assertEqual(rn0.pads(), ())
         rn1 = RangeSetND([['01-02', '003'], ['01-02', '004'], ['02-06', '006-009,411']])
-        self.assertEqual(str(rn1), "02-06; 006-009,411\n01-02; 003-004\n")
+        self.assertEqual(str(rn1), "03-06; 006-009,411\n02; 003-004,006-009,411\n01; 003-004\n")
         self.assertEqual(len(rn1), 29)
         self.assertEqual(rn1.pads(), (2, 3))
-        # Note: padding mismatch is NOT supported by ClusterShell
-        # We just track any regressions here (MAY CHANGE!)
+        # Note: mixed lengths zero-padding supported in ClusterShell v1.9
         rn1 = RangeSetND([['01-02', '003'], ['01-02', '0101'], ['02-06', '006-009,411']])
-        # here 0101 padding is changed to 101
-        self.assertEqual(str(rn1), '02-06; 006-009,411\n01-02; 003,101\n')
+        # before v1.9: 0101 padding was changed to 101
+        self.assertEqual(str(rn1), '03-06; 006-009,411\n02; 003,006-009,411,0101\n01; 003,0101\n')
         self.assertEqual(len(rn1), 29)
-        self.assertEqual(rn1.pads(), (2, 3))
+        self.assertEqual(rn1.pads(), (2, 4))
         rn1 = RangeSetND([['01-02', '0003'], ['01-02', '004'], ['02-06', '006-009,411']])
-        # here 004 padding is changed to 0004
-        self.assertEqual(str(rn1), '02-06; 006-009,411\n01-02; 0003-0004\n')
+        # before v1.9: 004 padding was wrongly changed to 0004
+        self.assertEqual(str(rn1), '03-06; 006-009,411\n02; 004,006-009,411,0003\n01; 004,0003\n')
         self.assertEqual(len(rn1), 29)
         self.assertEqual(rn1.pads(), (2, 4)) # pads() returns max padding length by axis
 
