@@ -3,8 +3,6 @@
 
 """Unit test for ClusterShell Task (distant, pdsh worker)"""
 
-import shutil
-
 from TLib import HOSTNAME, make_temp_filename, make_temp_dir
 from ClusterShell.Event import EventHandler
 from ClusterShell.Task import *
@@ -12,6 +10,7 @@ from ClusterShell.Worker.Worker import WorkerBadArgumentError
 from ClusterShell.Worker.Pdsh import WorkerPdsh
 from ClusterShell.Worker.EngineClient import *
 
+import shutil
 import socket
 import unittest
 
@@ -63,15 +62,15 @@ class TaskDistantPdshMixin(object):
         dest = make_temp_dir('testLocalhostExplicitPdshCopyWithOptions')
         self._task.set_info("pdcp_path", "pdcp -p")
         try:
-            worker = WorkerPdsh(HOSTNAME, source="/etc/hosts", dest=dest,
+            worker = WorkerPdsh(HOSTNAME, source="/etc/hosts", dest=dest.name,
                                 handler=None)
             self._task.schedule(worker)
             self._task.resume()
             self.assertEqual(self._task.max_retcode(), 0)
-            self.assertTrue(os.path.exists(os.path.join(dest, "hosts")))
+            self.assertTrue(os.path.exists(os.path.join(dest.name, "hosts")))
         finally:
-            os.unlink(os.path.join(dest, "hosts"))
-            os.rmdir(dest)
+            os.unlink(os.path.join(dest.name, "hosts"))
+            dest.cleanup()
         # clear options after test
         task_cleanup()
         self.assertEqual(task_self().info("pdcp_path"), None)
@@ -82,18 +81,18 @@ class TaskDistantPdshMixin(object):
         # pdcp worker doesn't create custom destination directory
         dtmp_dst = make_temp_dir('testLocalhostExplicitPdshCopyDir')
         try:
-            os.mkdir(os.path.join(dtmp_src, "lev1_a"))
-            os.mkdir(os.path.join(dtmp_src, "lev1_b"))
-            os.mkdir(os.path.join(dtmp_src, "lev1_a", "lev2"))
-            worker = WorkerPdsh(HOSTNAME, source=dtmp_src,
-                                dest=dtmp_dst, handler=None, timeout=10)
+            os.mkdir(os.path.join(dtmp_src.name, "lev1_a"))
+            os.mkdir(os.path.join(dtmp_src.name, "lev1_b"))
+            os.mkdir(os.path.join(dtmp_src.name, "lev1_a", "lev2"))
+            worker = WorkerPdsh(HOSTNAME, source=dtmp_src.name,
+                                dest=dtmp_dst.name, handler=None, timeout=10)
             self._task.schedule(worker)
             self._task.resume()
-            self.assertTrue(os.path.exists(os.path.join(dtmp_dst, \
-                os.path.basename(dtmp_src), "lev1_a", "lev2")))
+            self.assertTrue(os.path.exists(os.path.join( \
+                    dtmp_dst.name, os.path.basename(dtmp_src.name), "lev1_a", "lev2")))
         finally:
-            shutil.rmtree(dtmp_dst, ignore_errors=True)
-            shutil.rmtree(dtmp_src, ignore_errors=True)
+            dtmp_dst.cleanup()
+            dtmp_src.cleanup()
 
     def testLocalhostExplicitPdshCopyDirPreserve(self):
         # test simple localhost preserve copy dir with explicit pdsh worker
@@ -101,19 +100,20 @@ class TaskDistantPdshMixin(object):
         # pdcp worker doesn't create custom destination directory
         dtmp_dst = make_temp_dir('testLocalhostExplicitPdshCopyDirPreserve')
         try:
-            os.mkdir(os.path.join(dtmp_src, "lev1_a"))
-            os.mkdir(os.path.join(dtmp_src, "lev1_b"))
-            os.mkdir(os.path.join(dtmp_src, "lev1_a", "lev2"))
-            worker = WorkerPdsh(HOSTNAME, source=dtmp_src, dest=dtmp_dst,
-                                handler=None, timeout=10, preserve=True)
+            os.mkdir(os.path.join(dtmp_src.name, "lev1_a"))
+            os.mkdir(os.path.join(dtmp_src.name, "lev1_b"))
+            os.mkdir(os.path.join(dtmp_src.name, "lev1_a", "lev2"))
+            worker = WorkerPdsh(HOSTNAME, source=dtmp_src.name,
+                                dest=dtmp_dst.name, handler=None, timeout=10,
+                                preserve=True)
             self._task.schedule(worker)
             self._task.resume()
-            self.assertTrue(os.path.exists(os.path.join(dtmp_dst,
-                                                        os.path.basename(dtmp_src),
-                                                        "lev1_a", "lev2")))
+            self.assertTrue(os.path.exists(os.path.join( \
+                    dtmp_dst.name, os.path.basename(dtmp_src.name),
+                    "lev1_a", "lev2")))
         finally:
-            shutil.rmtree(dtmp_dst, ignore_errors=True)
-            shutil.rmtree(dtmp_src, ignore_errors=True)
+            dtmp_dst.cleanup()
+            dtmp_src.cleanup()
 
     def testExplicitPdshWorker(self):
         # test simple localhost command with explicit pdsh worker
@@ -453,39 +453,42 @@ class TaskDistantPdshMixin(object):
         dtmp_src = make_temp_dir('src')
         dtmp_dst = make_temp_dir('testLocalhostExplicitPdshReverseCopyDir')
         try:
-            os.mkdir(os.path.join(dtmp_src, "lev1_a"))
-            os.mkdir(os.path.join(dtmp_src, "lev1_b"))
-            os.mkdir(os.path.join(dtmp_src, "lev1_a", "lev2"))
-            worker = WorkerPdsh(HOSTNAME, source=dtmp_src, dest=dtmp_dst,
-                                handler=None, timeout=30, reverse=True)
+            os.mkdir(os.path.join(dtmp_src.name, "lev1_a"))
+            os.mkdir(os.path.join(dtmp_src.name, "lev1_b"))
+            os.mkdir(os.path.join(dtmp_src.name, "lev1_a", "lev2"))
+            worker = WorkerPdsh(HOSTNAME, source=dtmp_src.name,
+                                dest=dtmp_dst.name, handler=None, timeout=30,
+                                reverse=True)
             self._task.schedule(worker)
             self._task.resume()
-            tgt = os.path.join(dtmp_dst, "%s.%s" % (os.path.basename(dtmp_src),
-                                                    HOSTNAME), "lev1_a", "lev2")
+            tgt = os.path.join(dtmp_dst.name, "%s.%s" % \
+                    (os.path.basename(dtmp_src.name), HOSTNAME), "lev1_a",
+                    "lev2")
             self.assertTrue(os.path.exists(tgt))
         finally:
-            shutil.rmtree(dtmp_dst, ignore_errors=True)
-            shutil.rmtree(dtmp_src, ignore_errors=True)
+            dtmp_dst.cleanup()
+            dtmp_src.cleanup()
 
     def testLocalhostExplicitPdshReverseCopyDirPreserve(self):
         # test simple localhost preserve rcopy dir with explicit pdsh worker
         dtmp_src = make_temp_dir('src')
-        dtmp_dst = make_temp_dir('testLocalhostExplicitPdshReverseCopyDirPreserve')
+        dtmp_dst = make_temp_dir('testLocalhostExplicitPdshRevCpDirPreserve')
         try:
-            os.mkdir(os.path.join(dtmp_src, "lev1_a"))
-            os.mkdir(os.path.join(dtmp_src, "lev1_b"))
-            os.mkdir(os.path.join(dtmp_src, "lev1_a", "lev2"))
-            worker = WorkerPdsh(HOSTNAME, source=dtmp_src, dest=dtmp_dst,
-                                handler=None, timeout=30, preserve=True,
-                                reverse=True)
+            os.mkdir(os.path.join(dtmp_src.name, "lev1_a"))
+            os.mkdir(os.path.join(dtmp_src.name, "lev1_b"))
+            os.mkdir(os.path.join(dtmp_src.name, "lev1_a", "lev2"))
+            worker = WorkerPdsh(HOSTNAME, source=dtmp_src.name,
+                                dest=dtmp_dst.name, handler=None, timeout=30,
+                                preserve=True, reverse=True)
             self._task.schedule(worker)
             self._task.resume()
-            tgt = os.path.join(dtmp_dst, "%s.%s" % (os.path.basename(dtmp_src),
-                                                    HOSTNAME), "lev1_a", "lev2")
+            tgt = os.path.join(dtmp_dst.name, "%s.%s" % \
+                    (os.path.basename(dtmp_src.name), HOSTNAME), "lev1_a",
+                    "lev2")
             self.assertTrue(os.path.exists(tgt))
         finally:
-            shutil.rmtree(dtmp_dst, ignore_errors=True)
-            shutil.rmtree(dtmp_src, ignore_errors=True)
+            dtmp_dst.cleanup()
+            dtmp_src.cleanup()
 
     class TEventHandlerEvCountChecker(EventHandler):
         """simple event count validator"""
